@@ -1,10 +1,11 @@
 import re
-
 from enum import IntEnum
-
+from typing import List, Match, Pattern
 
 # We only need to support numbers 1-150 for our purposes. If we needed more it might
 # make sense to use an existing roman numeral library.
+
+
 class RomanNumeral(IntEnum):
     C = 100
     XC = 90
@@ -17,12 +18,12 @@ class RomanNumeral(IntEnum):
     I = 1
 
 
-ROMAN_NUMERAL_REGEX = re.compile(
+ROMAN_NUMERAL_REGEX: Pattern[str] = re.compile(
     r"\b(?=[CLXVI]+\b)(C?)(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})\b",
     re.IGNORECASE | re.UNICODE,
 )
 
-ROMAN_NUMERALS_BIG_TO_SMALL = [
+ROMAN_NUMERALS_BIG_TO_SMALL: List[RomanNumeral] = [
     RomanNumeral.C,
     RomanNumeral.XC,
     RomanNumeral.L,
@@ -35,11 +36,11 @@ ROMAN_NUMERALS_BIG_TO_SMALL = [
 ]
 
 
-def convert_all_roman_numerals_to_integers(text):
+def convert_all_roman_numerals_to_integers(text: str) -> str:
     return ROMAN_NUMERAL_REGEX.sub(_convert_roman_numeral_match_to_integer, text)
 
 
-def _convert_roman_numeral_match_to_integer(match):
+def _convert_roman_numeral_match_to_integer(match: Match[str]):
     return str(_convert_roman_numeral_to_integer(match.group(0)))
 
 
